package com.ruoyi.menuex.mapper;

import com.baomidou.dynamic.datasource.annotation.DS;
import com.ruoyi.common.core.domain.entity.SysMenu;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 菜单表 数据层
 *
 * @author ruoyi
 */
public interface SysMenuExMapper {
    /**
     * 查询系统菜单列表
     *
     * @param menu 菜单信息
     * @return 菜单列表
     */
    @DS("menu")
    public List<SysMenu> selectMenuList(SysMenu menu);

    /**
     * 根据用户所有权限
     *
     * @return 权限列表
     */
    @DS("menu")
    public List<String> selectMenuPermsByMenuIdsAndStatus(@Param("menuIds") List<Long> menuIds, @Param("status") String status);

    /**
     * 查询指定角色ID绑定的菜单ID列表
     *
     * @param roleId 待查询的角色ID
     * @return 绑定的菜单ID列表
     */
    public List<Long> selectMenuIdsByRoleId(Long roleId);

    /**
     * 根据用户ID查询菜单ID列表，且角色状态为启用状态
     *
     * @param userId 用户ID
     * @return 菜单ID列表
     */
    public List<Long> selectMenuIdsByUserIdAndStatus(@Param("userId") Long userId, @Param("status") String status);

    /**
     * 根据用户ID查询菜单
     *
     * @return 菜单列表
     */
    @DS("menu")
    public List<SysMenu> selectMenuTreeAll();

    /**
     * 根据菜单ID列表查询菜单树
     *
     * @param menuIds 菜单ID列表
     * @return 菜单列表数据
     */
    @DS("menu")
    public List<SysMenu> selectMenuTreeByMenuIds(@Param("menuIds") List<Long> menuIds);

    /**
     * 根据指定ID列表查询父级菜单列表
     *
     * @param menuIds 菜单ID列表
     * @return 父级菜单ID列表
     */
    @DS("menu")
    public List<Long> selectMenuParentIdsByMenuIds(@Param("menuIds") List<Long> menuIds);

    /**
     * 根据菜单ID查询信息
     *
     * @param menuId 菜单ID
     * @return 菜单信息
     */
    @DS("menu")
    public SysMenu selectMenuById(Long menuId);

    /**
     * 是否存在菜单子节点
     *
     * @param menuId 菜单ID
     * @return 结果
     */
    @DS("menu")
    public int hasChildByMenuId(Long menuId);

    /**
     * 新增菜单信息
     *
     * @param menu 菜单信息
     * @return 结果
     */
    @DS("menu")
    public int insertMenu(SysMenu menu);

    /**
     * 修改菜单信息
     *
     * @param menu 菜单信息
     * @return 结果
     */
    @DS("menu")
    public int updateMenu(SysMenu menu);

    /**
     * 删除菜单管理信息
     *
     * @param menuId 菜单ID
     * @return 结果
     */
    @DS("menu")
    public int deleteMenuById(Long menuId);

    /**
     * 校验菜单名称是否唯一
     *
     * @param menuName 菜单名称
     * @param parentId 父菜单ID
     * @return 结果
     */
    @DS("menu")
    public SysMenu checkMenuNameUnique(@Param("menuName") String menuName, @Param("parentId") Long parentId);
}
